@@ -1,4 +1,3 @@
-
 import os
 import unittest
 from pathlib import Path
@@ -8,23 +7,19 @@ cwd = os.getcwd()
 
 class test_object_properties(unittest.TestCase):
     def test_make_parametric_ball_rector(self):
-        """ Runs the example and checks the output files are produced"""
+        """Runs the example and checks the output files are produced"""
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_reactors"))
-        output_filenames = ['plasma.stp',
-            'inboard_tf_coils.stp',
-            'center_column_shield.stp',
-            'divertor_upper.stp',
-            'divertor_lower.stp',
-            'extra_blanket_upper.stp',
-            'extra_firstwall_upper.stp',
-            'extra_blanket_rear_wall_upper.stp',
-            'extra_blanket_lower.stp',
-            'extra_firstwall_lower.stp',
-            'extra_blanket_rear_wall_lower.stp',
-            'firstwall.stp', 'blanket.stp',
-            'blanket_rear_wall.stp',
-            'Graveyard.stp']
+        output_filenames = [
+            "plasma.stp",
+            "inboard_tf_coils.stp",
+            "center_column_shield.stp",
+            "divertor.stp",
+            "firstwall.stp",
+            "blanket.stp",
+            "blanket_rear_wall.stp",
+            "Graveyard.stp",
+        ]
         for output_filename in output_filenames:
             os.system("rm " + output_filename)
         os.system("python make_parametric_ball_reactor.py")
@@ -32,8 +27,61 @@ class test_object_properties(unittest.TestCase):
             assert Path(output_filename).exists() is True
             os.system("rm " + output_filename)
 
+    def test_make_parametric_single_null_ball_reactor(self):
+        """Runs the example and checks the output files are produced"""
+        os.chdir(Path(cwd))
+        os.chdir(Path("examples/example_parametric_reactors"))
+        output_filenames = [
+            "blanket_rear_wall.stp",
+            "blanket.stp",
+            "center_column_shield.stp",
+            "divertor.stp",
+            "firstwall.stp",
+            "Graveyard.stp",
+            "inboard_tf_coils.stp",
+            "pf_coil_0.stp",
+            "pf_coil_1.stp",
+            "pf_coil_2.stp",
+            "pf_coil_3.stp",
+            "plasma.stp",
+            "tf_coil.stp"
+        ]
+        for output_filename in output_filenames:
+            os.system("rm " + output_filename)
+        os.system("python make_parametric_single_null_ball_reactor.py")
+        for output_filename in output_filenames:
+            assert Path(output_filename).exists() is True
+            os.system("rm " + output_filename)
+
+    def test_make_parametric_single_null_submersion_reactor(self):
+        """Runs the example and checks the output files are produced"""
+        os.chdir(Path(cwd))
+        os.chdir(Path("examples/example_parametric_reactors"))
+        output_filenames = [
+            'inboard_tf_coils.stp',
+            'center_column_shield.stp',
+            'plasma.stp',
+            'divertor.stp',
+            'supports.stp',
+            'outboard_firstwall.stp',
+            'blanket.stp',
+            'outboard_rear_blanket_wall.stp',
+            'outboard_tf_coil.stp',
+            'pf_coil_0.stp',
+            'pf_coil_1.stp',
+            'pf_coil_2.stp',
+            'pf_coil_3.stp',
+            'Graveyard.stp'
+        ]
+        for output_filename in output_filenames:
+            os.system("rm " + output_filename)
+        os.system("python make_parametric_single_null_submersion_ball_reactor.py")
+        for output_filename in output_filenames:
+            assert Path(output_filename).exists() is True
+            os.system("rm " + output_filename)
+
     def test_make_blanket_from_points(self):
-        """ Runs the example and checks the output files are produced"""
+        """Runs the example and checks the output files are produced"""
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_shapes"))
         output_filename = "blanket_from_points.stp"
@@ -43,7 +91,7 @@ class test_object_properties(unittest.TestCase):
         os.system("rm " + output_filename)
 
     def test_make_blanket_parametrically(self):
-        """ Runs the example and checks the output files are produced"""
+        """Runs the example and checks the output files are produced"""
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_shapes"))
         output_filename = "blanket_from_parameters.stp"
@@ -53,7 +101,7 @@ class test_object_properties(unittest.TestCase):
         os.system("rm " + output_filename)
 
     def test_make_CAD_from_points(self):
-        """ Runs the example and checks the output files are produced"""
+        """Runs the example and checks the output files are produced"""
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_shapes"))
         output_filenames = [
@@ -72,7 +120,7 @@ class test_object_properties(unittest.TestCase):
             os.system("rm " + output_filename)
 
     def test_make_all_parametric_components(self):
-        """ Runs the example and checks the output files are produced"""
+        """Runs the example and checks the output files are produced"""
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_components"))
         output_filenames = [
@@ -92,6 +140,8 @@ class test_object_properties(unittest.TestCase):
             "blanket_arc_h.stp",
             "tf_coil_rectangle.stp",
             "toroidal_field_coil_coat_hanger.stp",
+            "toroidal_field_coil_triple_arc.stp",
+            "toroidal_field_coil_princeton_d.stp"
         ]
         for output_filename in output_filenames:
             os.system("rm " + output_filename)
@@ -100,9 +150,8 @@ class test_object_properties(unittest.TestCase):
             assert Path(output_filename).exists() is True
             os.system("rm " + output_filename)
 
-
     def test_make_can_reactor_from_parameters(self):
-        """ Runs the example and checks the output files are produced"""
+        """Runs the example and checks the output files are produced"""
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_shapes"))
         output_filenames = [
@@ -123,7 +172,7 @@ class test_object_properties(unittest.TestCase):
             os.system("rm " + output_filename)
 
     def test_make_can_reactor_from_points(self):
-        """ Runs the example and checks the output files are produced"""
+        """Runs the example and checks the output files are produced"""
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_shapes"))
         output_filenames = [
@@ -144,7 +193,7 @@ class test_object_properties(unittest.TestCase):
             os.system("rm " + output_filename)
 
     def test_make_plasma(self):
-        """ Runs the example and checks the output files are produced"""
+        """Runs the example and checks the output files are produced"""
         os.chdir(Path(cwd))
         os.chdir(Path("examples/example_parametric_components"))
         output_filenames = [
